package WebGUI::i18n::German::Asset_Photo;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1229722493',
    'message' => 'Foto'
  },
  'comment message' => {
    'lastUpdated' => '1229722523',
    'message' => 'Ihr Kommentar wurde hinzugefügt. <a href="%s">Zurück zum Foto</a>.'
  },
  'commentForm error no bodyText' => {
    'lastUpdated' => '1229722538',
    'message' => 'Es wurde kein Text eingegeben. Bitte geben Sie einen Text ein, um einen Kommentar zu erzeugen!'
  },
  'commentForm error no commentId' => {
    'lastUpdated' => '1229722593',
    'message' => 'Es wurde keine ID für den Kommentar vergeben. Dies bedeutet, dass ein Problem mit der Vorlage besteht. Bitte informieren Sie einen Administrator!'
  },
  'delete message' => {
    'lastUpdated' => '1229722618',
    'message' => 'Das Foto wurde gelöscht. <a href="%s">Zurück zum Album</a>'
  },
  'editCommentSave message' => {
    'lastUpdated' => '1223576793',
    'message' => 'Die Bemerkung wurde aktualisiert. <a href="%s">Zurück zum Bild</a>'
  },
  'editForm cancel' => {
    'lastUpdated' => '1217314939',
    'message' => 'Abbrechen'
  },
  'editForm friendsOnly' => {
    'lastUpdated' => '1217314948',
    'message' => 'Nur Freunde'
  },
  'editForm keywords' => {
    'lastUpdated' => '1229722641',
    'message' => 'Stichwörter'
  },
  'editForm location' => {
    'lastUpdated' => '1226016555',
    'message' => 'Ort'
  },
  'editForm photo new' => {
    'lastUpdated' => '1229726315',
    'message' => 'Neues Foto'
  },
  'editForm photo replace' => {
    'lastUpdated' => '1229726325',
    'message' => 'Foto ersetzen'
  },
  'editForm save' => {
    'lastUpdated' => '1217314980',
    'message' => 'Speichern'
  },
  'editForm synopsis label' => {
    'lastUpdated' => '1230111406',
    'message' => 'Beschreibung'
  },
  'editForm title label' => {
    'lastUpdated' => '1217315028',
    'message' => 'Titel'
  },
  'error no image' => {
    'lastUpdated' => '1276643116',
    'message' => 'Sie müssen ein Bild zum Hochladen auswählen.'
  },
  'error no space' => {
    'lastUpdated' => '1229722689',
    'message' => 'Sie haben nicht genug Speicherplatz, um diese Datei hochzuladen.'
  },
  'form comment save comment' => {
    'lastUpdated' => '1234945263',
    'message' => 'Kommentar sichern'
  },
  'help commentForm body' => {
    'lastUpdated' => '1229771116',
    'message' => 'Diese Variablen sind in der Ansicht zur Erstellung von Kommentaren verfügbar.'
  },
  'help commentForm title' => {
    'lastUpdated' => '1229771262',
    'message' => 'Foto, Kommentar hinzufügen'
  },
  'help common body' => {
    'lastUpdated' => '1229771147',
    'message' => 'Diese Variablen sind in allen Ansichten des Fotos verfügbar.'
  },
  'help common title' => {
    'lastUpdated' => '1229770863',
    'message' => 'Foto, allgemein'
  },
  'help delete body' => {
    'lastUpdated' => '1230111463',
    'message' => 'Bestätigung der Löschung eines Foto-Assets.'
  },
  'help delete title' => {
    'lastUpdated' => '1229770917',
    'message' => 'Foto, löschen'
  },
  'help edit body' => {
    'lastUpdated' => '1229771204',
    'message' => 'Diese Variablen sind in der Ansicht zum Hinzufügen bzw. Bearbeiten von Fotos verfügbar.'
  },
  'help edit title' => {
    'lastUpdated' => '1229770908',
    'message' => 'Foto, bearbeiten'
  },
  'help editComment body' => {
    'lastUpdated' => '1229771375',
    'message' => 'Diese Variablen sind in der Ansicht zur Bearbeitung von Kommentaren verfügbar.'
  },
  'help editComment title' => {
    'lastUpdated' => '1229771249',
    'message' => 'Foto, Kommentar bearbeiten'
  },
  'help makeShortcut body' => {
    'lastUpdated' => '1229773085',
    'message' => 'Diese Variablen sind in der Ansicht zur Erstellung von Verknüpfungen verfügbar.'
  },
  'help makeShortcut title' => {
    'lastUpdated' => '1229773055',
    'message' => 'Foto, Verknüpfung erstellen'
  },
  'help view body' => {
    'lastUpdated' => '1229771525',
    'message' => 'Diese Variablen sind in der Standardansicht des Fotos verfügbar.'
  },
  'help view title' => {
    'lastUpdated' => '1229770965',
    'message' => 'Foto, Standardansicht'
  },
  'helpvar album_menuTitle' => {
    'lastUpdated' => '1229725884',
    'message' => 'Der Menütitel des Albums, welches diese Datei enthält.'
  },
  'helpvar album_thumbnailUrl' => {
    'lastUpdated' => '1229725757',
    'message' => 'Der URL des Vorschaubildes des Albums, welches diese Datei enthält.'
  },
  'helpvar album_title' => {
    'lastUpdated' => '1229725769',
    'message' => 'Der Titel des Albums, welches diese Datei enthält.'
  },
  'helpvar album_url' => {
    'lastUpdated' => '1229725782',
    'message' => 'Der URL des Albums, welches diese Datei enthält.'
  },
  'helpvar canComment' => {
    'lastUpdated' => '1229771393',
    'message' => 'Eine Variable die wahr ist, falls der aktuelle Benutzer dieses Foto kommentieren darf.'
  },
  'helpvar canEdit' => {
    'lastUpdated' => '1229771408',
    'message' => 'Eine Variable die wahr ist, falls der aktuelle Benutzer dieses Foto bearbeiten darf.'
  },
  'helpvar commentForm_bodyText' => {
    'lastUpdated' => '1201607944',
    'message' => 'Der Inhalt eines Kommentars. Ein Rich Editor wurde für die Vorgaänger (Parent) Galerie konfiguriert.'
  },
  'helpvar commentForm_end' => {
    'lastUpdated' => '1229726006',
    'message' => 'Das Ende des Formulars für Kommentare.'
  },
  'helpvar commentForm_start' => {
    'lastUpdated' => '1229726030',
    'message' => 'Der Beginn des Formulars für Kommentare.'
  },
  'helpvar commentForm_submit' => {
    'lastUpdated' => '1229726118',
    'message' => 'Übergebe das Formular für Kommentare.'
  },
  'helpvar commentLoop' => {
    'lastUpdated' => '1229725579',
    'message' => 'Schleife über eine Seite mit Kommentaren zu diesem Foto.'
  },
  'helpvar commentLoop bodyText' => {
    'lastUpdated' => '1229725541',
    'message' => 'Der Inhalt des Kommentars.'
  },
  'helpvar commentLoop creationDate' => {
    'lastUpdated' => '1229725530',
    'message' => 'Erstellungsdatum des Kommentars.'
  },
  'helpvar commentLoop url_deleteComment' => {
    'lastUpdated' => '1229725518',
    'message' => 'Der URL zum Löschen dieses Kommentars.'
  },
  'helpvar commentLoop userId' => {
    'lastUpdated' => '1230126892',
    'message' => 'Die ID des Benutzers, der den Kommentar erstellt hat.'
  },
  'helpvar commentLoop username' => {
    'lastUpdated' => '1229725468',
    'message' => 'Der Benutzername des Benutzers, der den Kommentar erstellt hat.'
  },
  'helpvar commentLoop visitorIp' => {
    'lastUpdated' => '1229725432',
    'message' => 'Die IP-Adresse des Benutzers, falls dieser ein nicht-registrierter Besucher ist.'
  },
  'helpvar commentLoop_pageBar' => {
    'lastUpdated' => '1229725388',
    'message' => 'Die Leiste, um durch die Seiten mit Kommentaren zu navigieren.'
  },
  'helpvar error' => {
    'lastUpdated' => '1229725102',
    'message' => 'Die i18n-Fehlermeldung.'
  },
  'helpvar errors' => {
    'lastUpdated' => '1229725063',
    'message' => 'Eine Schleife mit Fehlermeldungen zur Anzeige gegenüber dem Benutzer.'
  },
  'helpvar exifLoop' => {
    'lastUpdated' => '1229724973',
    'message' => 'Schleife über EXIF-Tags.'
  },
  'helpvar exifLoop tag' => {
    'lastUpdated' => '1229724958',
    'message' => 'Der Name des EXIF-Tags.'
  },
  'helpvar exifLoop value' => {
    'lastUpdated' => '1229724947',
    'message' => 'Der Wert des EXIF-Tags.'
  },
  'helpvar exif_' => {
    'lastUpdated' => '1229724920',
    'message' => 'Jeder EXIF-Tag kann über seinen Namen referenziert werden.'
  },
  'helpvar fileUrl' => {
    'lastUpdated' => '1229724886',
    'message' => 'Der URL zum Foto in Originalgröße.'
  },
  'helpvar firstFile_thumbnailUrl' => {
    'lastUpdated' => '1270629886',
    'message' => 'URL des Vorschaubildes für die erste Datei im Album.'
  },
  'helpvar firstFile_title' => {
    'lastUpdated' => '1270629906',
    'message' => 'Titel der ersten Datei im Album.'
  },
  'helpvar firstFile_url' => {
    'lastUpdated' => '1270629922',
    'message' => 'URL der ersten Datei im Album.'
  },
  'helpvar form_end' => {
    'lastUpdated' => '1229725647',
    'message' => 'Das Ende des Formulars.'
  },
  'helpvar form_friendsOnly' => {
    'lastUpdated' => '1229724787',
    'message' => 'Foto nur für Freunde?'
  },
  'helpvar form_keywords' => {
    'lastUpdated' => '1229724773',
    'message' => 'Die Stichwörter für das Foto.'
  },
  'helpvar form_location' => {
    'lastUpdated' => '1229724744',
    'message' => 'Der Ort, an dem das Foto aufgenommen wurde.'
  },
  'helpvar form_parentId' => {
    'lastUpdated' => '1229724723',
    'message' => 'Wählen Sie das Album, in dem der Verweis angelegt werden soll!'
  },
  'helpvar form_photo' => {
    'lastUpdated' => '1229724681',
    'message' => 'Das hochzuladende Foto.'
  },
  'helpvar form_start' => {
    'lastUpdated' => '1201608530',
    'message' => 'Beginn des Formulars.'
  },
  'helpvar form_submit' => {
    'lastUpdated' => '1229724653',
    'message' => 'Übergebe das Formular.'
  },
  'helpvar form_synopsis' => {
    'lastUpdated' => '1229724607',
    'message' => 'Die Beschriftung des Fotos.'
  },
  'helpvar form_title' => {
    'lastUpdated' => '1229724589',
    'message' => 'Der Titel des Fotos.'
  },
  'helpvar gallery_menuTitle' => {
    'lastUpdated' => '1229724578',
    'message' => 'Der Menütitel der Galerie, die diese Datei enthält.'
  },
  'helpvar gallery_title' => {
    'lastUpdated' => '1229724556',
    'message' => 'Der Titel der Galerie, die diese Datei enthält.'
  },
  'helpvar gallery_url' => {
    'lastUpdated' => '1229724540',
    'message' => 'Der URL der Galerie, die diese Datei enthält.'
  },
  'helpvar isNewPhoto' => {
    'lastUpdated' => '1217315374',
    'message' => 'Diese Variable ist wahr, falls der Benutzer ein neues Photo hinzufügt'
  },
  'helpvar isPending' => {
    'lastUpdated' => '1229724516',
    'message' => 'Variable die wahr ist, falls das Foto noch nicht freigegeben wurde. Benutzer, die berechtigt sind, das Foto zu bearbeiten, dürfen es schon sehen noch bevor es freigegeben wurde.'
  },
  'helpvar keyword' => {
    'lastUpdated' => '1229724332',
    'message' => 'Das Schlüsselwort'
  },
  'helpvar keywords' => {
    'lastUpdated' => '1229724819',
    'message' => 'Eine Schleife mit Stichwörtern, die diesem Foto zugeordnet sind.'
  },
  'helpvar lastFile_thumbnailUrl' => {
    'lastUpdated' => '1270629956',
    'message' => 'URL des Vorschaubildes für die letzte Datei im Album'
  },
  'helpvar lastFile_title' => {
    'lastUpdated' => '1270629980',
    'message' => 'Titel der letzte Datei im Album.'
  },
  'helpvar lastFile_url' => {
    'lastUpdated' => '1270630000',
    'message' => 'URL der letzten Datei im Album.'
  },
  'helpvar nextFile_thumbnailUrl' => {
    'lastUpdated' => '1270630058',
    'message' => 'URL des Vorschaubildes für die nächste Datei im Album. Nicht definiert, wenn keine nächste Datei existiert.'
  },
  'helpvar nextFile_title' => {
    'lastUpdated' => '1270630099',
    'message' => 'Titel der nächsten Datei im Album. Nicht definiert, wenn keine nächste Datei existiert.'
  },
  'helpvar nextFile_url' => {
    'lastUpdated' => '1270630134',
    'message' => 'URL der nächsten Datei im Album. Nicht definiert, wenn keine nächste Datei existiert.'
  },
  'helpvar numberOfComments' => {
    'lastUpdated' => '1229724284',
    'message' => 'Die Anzahl der Kommentare für dieses Foto.'
  },
  'helpvar ownerAlias' => {
    'lastUpdated' => '1275484954',
    'message' => 'Alias des Benutzers, der das Photo eingestellt hat. Nutzername ist Standard, falls keine Alias festgelegt ist.'
  },
  'helpvar ownerId' => {
    'lastUpdated' => '1275484986',
    'message' => 'ID des Benutzers, der des Foto eingestellt hat.'
  },
  'helpvar ownerProfileUrl' => {
    'lastUpdated' => '1275485034',
    'message' => 'URL zum Benutzerprofil des Foto Einstellers.'
  },
  'helpvar ownerUsername' => {
    'lastUpdated' => '1229724250',
    'message' => 'Der Benutzername des Benutzers, der dieses Foto übermittelt hat.'
  },
  'helpvar previousFile_thumbnailUrl' => {
    'lastUpdated' => '1270630189',
    'message' => 'URL des Vorschaubildes für die vorhergehenden Datei im Album. Nicht definiert, wenn keine vorhergehende Datei existiert.'
  },
  'helpvar previousFile_title' => {
    'lastUpdated' => '1270630216',
    'message' => 'Titel der vorhergehenden Datei im Album. Nicht definiert, wenn keine vorhergehende Datei existiert.'
  },
  'helpvar previousFile_url' => {
    'lastUpdated' => '1270630156',
    'message' => 'URL der vorhergehenden Datei im Album. Nicht definiert, wenn keine vorhergehende Datei existiert.'
  },
  'helpvar resolutions_' => {
    'lastUpdated' => '1229724220',
    'message' => 'Der URL zu einer bestimmten Auflösung. Der URL für eine Auflösung von 800 Pixeln wäre als "resolutions_800" definiert.'
  },
  'helpvar resolutions_loop' => {
    'lastUpdated' => '1229724058',
    'message' => 'Die verfügbaren Auflösungen des Fotos für den Download.'
  },
  'helpvar resolutions_loop resolution' => {
    'lastUpdated' => '1229724033',
    'message' => 'Die Auflösung des Fotos.'
  },
  'helpvar resolutions_loop url_download' => {
    'lastUpdated' => '1229723995',
    'message' => 'Der URL zum Download des Fotos in einer bestimmten Auflösung.'
  },
  'helpvar synopsis_textonly' => {
    'lastUpdated' => '1229724018',
    'message' => 'Das Feld "Synopsis" ohne HTML-Code.'
  },
  'helpvar thumbnailUrl' => {
    'lastUpdated' => '1229723961',
    'message' => 'Der URL zum Vorschaubild dieses Fotos.'
  },
  'helpvar url_addArchive' => {
    'lastUpdated' => '1229723948',
    'message' => 'Der URL zum Hinzufügen eines Archivs zum übergeordneten Album.'
  },
  'helpvar url_album' => {
    'lastUpdated' => '1229723873',
    'message' => 'Der URL des Albums, welches diese Datei enthält.'
  },
  'helpvar url_delete' => {
    'lastUpdated' => '1229723843',
    'message' => 'Der URL zum Löschen dieses Fotos.'
  },
  'helpvar url_demote' => {
    'lastUpdated' => '1229723829',
    'message' => 'Der URL zur Zurückstufung des Ranges dieses Fotos. Bringt den Benutzer direkt zum Bearbeitungs-Formular der übergeordneten Galerie.'
  },
  'helpvar url_edit' => {
    'lastUpdated' => '1229723710',
    'message' => 'Der URL zum Bearbeiten dieses Fotos.'
  },
  'helpvar url_gallery' => {
    'lastUpdated' => '1229723690',
    'message' => 'Der URL zur Galerie, die dieses Foto enthält.'
  },
  'helpvar url_listFilesForOwner' => {
    'lastUpdated' => '1229723619',
    'message' => 'Der URL zur Auflistung der Dateien und Alben, die der Besitzer dieses Fotos übermittelt hat.'
  },
  'helpvar url_makeShortcut' => {
    'lastUpdated' => '1229773109',
    'message' => 'Der URL zum Erzeugen einer Verknüpfung auf dieses Foto.'
  },
  'helpvar url_promote' => {
    'lastUpdated' => '1229723458',
    'message' => 'Der URL zur Verbesserung des Ranges dieses Fotos. Bringt den Benutzer direkt zum Bearbeitungs-Formular der übergeordneten Galerie.'
  },
  'helpvar url_searchKeyword' => {
    'lastUpdated' => '1229723381',
    'message' => 'Der URL zur Suchseite der Galerie für dieses Schlüsselwort.'
  },
  'helpvar url_searchKeywordUser' => {
    'lastUpdated' => '1229723357',
    'message' => 'Der URL zur Suchseite der Galerie für dieses Schlüsselwort. Die Suche ist auf Fotos des aktuellen Benutzers beschränkt.'
  },
  'helpvar url_slideshow' => {
    'lastUpdated' => '1229723905',
    'message' => 'Der URL zur Diashow-Ansicht des Albums, welches diese Datei enthält.'
  },
  'helpvar url_thumbnails' => {
    'lastUpdated' => '1229723890',
    'message' => 'Der URL zur Vorschaubild-Ansicht des Albums, welches diese Datei enthält.'
  },
  'helpvar url_yes' => {
    'lastUpdated' => '1229723186',
    'message' => 'Bestätigen Sie das Löschen dieses Fotos.'
  },
  'hide' => {
    'lastUpdated' => '1234945277',
    'message' => 'Verbergen'
  },
  'more details' => {
    'lastUpdated' => '1234945334',
    'message' => 'Mehr Details'
  },
  'save message' => {
    'lastUpdated' => '1229723159',
    'message' => 'Ihr Foto wartet auf Freigabe für die Veröffentlichung. <a href="%s">Foto ansehen</a>. <a href="%s">Ein weiteres Foto hinzufügen</a>.'
  },
  'template assetName' => {
    'lastUpdated' => '1229723026',
    'message' => 'Foto'
  },
  'template comment add title' => {
    'lastUpdated' => '1229978248',
    'message' => 'Kommentar hinzufügen'
  },
  'template comment creationDate' => {
    'lastUpdated' => '1229978237',
    'message' => 'Hinzugefügt am'
  },
  'template comment delete confirm' => {
    'lastUpdated' => '1266396348',
    'message' => 'Sind Sie sicher, dass Sie diesen Kommentar entfernen wollen?'
  },
  'template comment edit comment' => {
    'lastUpdated' => '1234945324',
    'message' => 'Kommentar ändern'
  },
  'template comment edit title' => {
    'lastUpdated' => '1230117461',
    'message' => 'Bearbeiten'
  },
  'template comments title' => {
    'lastUpdated' => '1217315772',
    'message' => 'Kommentare'
  },
  'template creationDate' => {
    'lastUpdated' => '1217315780',
    'message' => 'Hochgeladen am'
  },
  'template delete albums' => {
    'lastUpdated' => '1229722986',
    'message' => 'Das Foto befindet sich in den folgenden Alben:'
  },
  'template delete message' => {
    'lastUpdated' => '1234388098',
    'message' => 'Sind Sie sicher, dass Sie dieses Foto löschen wollen?'
  },
  'template error happened' => {
    'lastUpdated' => '1217315843',
    'message' => 'Beim Bearbeiten Ihrer Anfrage ist ein Fehler aufgetreten.'
  },
  'template fileUrl' => {
    'lastUpdated' => '1229722868',
    'message' => 'Bild in voller Größe betrachten'
  },
  'template filesForUser' => {
    'lastUpdated' => '1275485046',
    'message' => 'mehr Fotos'
  },
  'template friendsOnly label' => {
    'lastUpdated' => '1226016599',
    'message' => 'Privat'
  },
  'template friendsOnly no' => {
    'lastUpdated' => '1229722855',
    'message' => 'Öffentlich'
  },
  'template friendsOnly yes' => {
    'lastUpdated' => '1217315902',
    'message' => 'Nur Freunde'
  },
  'template keywords' => {
    'lastUpdated' => '1229724838',
    'message' => 'Stichwörter'
  },
  'template location' => {
    'lastUpdated' => '1226016613',
    'message' => 'Ort'
  },
  'template makeShortcut album' => {
    'lastUpdated' => '1217315918',
    'message' => 'Album'
  },
  'template makeShortcut file' => {
    'lastUpdated' => '1217315923',
    'message' => 'Datei'
  },
  'template makeShortcut title' => {
    'lastUpdated' => '1229773142',
    'message' => 'Verknüpfung erstellen'
  },
  'template url_album' => {
    'lastUpdated' => '1229722834',
    'message' => 'Zurück zum Album'
  },
  'template url_delete' => {
    'lastUpdated' => '1229722845',
    'message' => 'Foto löschen'
  },
  'template url_deleteComment' => {
    'lastUpdated' => '1230117270',
    'message' => 'Löschen'
  },
  'template url_edit' => {
    'lastUpdated' => '1229722812',
    'message' => 'Foto bearbeiten'
  },
  'template url_makeShortcut' => {
    'lastUpdated' => '1229773163',
    'message' => 'Verknüpfung erstellen'
  },
  'template view available resolutions' => {
    'lastUpdated' => '1234945308',
    'message' => 'Verfügbare Auflösungen'
  },
  'template view details' => {
    'lastUpdated' => '1234945291',
    'message' => 'Details'
  },
  'template view title' => {
    'lastUpdated' => '1229722484',
    'message' => 'Foto-Details'
  },
  'template views' => {
    'lastUpdated' => '1229722824',
    'message' => 'Ansichten'
  }
}
;

1;
